@@ -3,7 +3,7 @@ name = "esp300"
 hwid = ["10C4:EA60"]
 serial_number = ["20210204471"]
 
-class ESP300:
+class instrument:
     def __init__(self, port):
         self.rm = pyvisa.ResourceManager()
         current_port = port.name
